@@ -3,7 +3,9 @@ import logging
 import traceback
 from concurrent.futures.process import ProcessPoolExecutor
 from dataclasses import dataclass
-from typing import Dict, List, Optional, Sequence, Tuple, Union, Callable
+from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+
+from blspy import AugSchemeMPL, G1Element
 
 from chia.consensus.block_header_validation import validate_finished_header_block
 from chia.consensus.block_record import BlockRecord
@@ -23,9 +25,10 @@ from chia.types.generator_types import BlockGenerator
 from chia.types.header_block import HeaderBlock
 from chia.types.unfinished_block import UnfinishedBlock
 from chia.util.block_cache import BlockCache
+from chia.util.condition_tools import pkm_pairs
 from chia.util.errors import Err, ValidationError
 from chia.util.generator_tools import get_block_header, tx_removals_and_additions
-from chia.util.ints import uint16, uint64, uint32
+from chia.util.ints import uint16, uint32, uint64
 from chia.util.streamable import Streamable, dataclass_from_dict, streamable
 
 log = logging.getLogger(__name__)
@@ -37,6 +40,7 @@ class PreValidationResult(Streamable):
     error: Optional[uint16]
     required_iters: Optional[uint64]  # Iff error is None
     npc_result: Optional[NPCResult]  # Iff error is None and block is a transaction block
+    validated_signature: bool
 
 
 def batch_pre_validate_blocks(
@@ -49,14 +53,17 @@ def batch_pre_validate_blocks(
     check_filter: bool,
     expected_difficulty: List[uint64],
     expected_sub_slot_iters: List[uint64],
+    validate_signatures: bool,
 ) -> List[bytes]:
-    blocks = {}
+    blocks: Dict[bytes, BlockRecord] = {}
     for k, v in blocks_pickled.items():
         blocks[k] = BlockRecord.from_bytes(v)
     results: List[PreValidationResult] = []
     constants: ConsensusConstants = dataclass_from_dict(ConsensusConstants, constants_dict)
     if full_blocks_pickled is not None and header_blocks_pickled is not None:
         assert ValueError("Only one should be passed here")
+
+    # In this case, we are validating full blocks, not headers
     if full_blocks_pickled is not None:
         for i in range(len(full_blocks_pickled)):
             try:
@@ -82,14 +89,21 @@ def batch_pre_validate_blocks(
                         block_generator,
                         min(constants.MAX_BLOCK_COST_CLVM, block.transactions_info.cost),
                         cost_per_byte=constants.COST_PER_BYTE,
-                        safe_mode=True,
+                        mempool_mode=False,
+                        height=block.height,
                     )
                     removals, tx_additions = tx_removals_and_additions(npc_result.npc_list)
+                if npc_result is not None and npc_result.error is not None:
+                    results.append(PreValidationResult(uint16(npc_result.error), None, npc_result, False))
+                    continue
 
                 header_block = get_block_header(block, tx_additions, removals)
+                # TODO: address hint error and remove ignore
+                #       error: Argument 1 to "BlockCache" has incompatible type "Dict[bytes, BlockRecord]"; expected
+                #       "Dict[bytes32, BlockRecord]"  [arg-type]
                 required_iters, error = validate_finished_header_block(
                     constants,
-                    BlockCache(blocks),
+                    BlockCache(blocks),  # type: ignore[arg-type]
                     header_block,
                     check_filter,
                     expected_difficulty[i],
@@ -99,18 +113,42 @@ def batch_pre_validate_blocks(
                 if error is not None:
                     error_int = uint16(error.code.value)
 
-                results.append(PreValidationResult(error_int, required_iters, npc_result))
+                successfully_validated_signatures = False
+                # If we failed CLVM, no need to validate signature, the block is already invalid
+                if error_int is None:
+
+                    # If this is False, it means either we don't have a signature (not a tx block) or we have an invalid
+                    # signature (which also puts in an error) or we didn't validate the signature because we want to
+                    # validate it later. receive_block will attempt to validate the signature later.
+                    if validate_signatures:
+                        if npc_result is not None and block.transactions_info is not None:
+                            pairs_pks, pairs_msgs = pkm_pairs(npc_result.npc_list, constants.AGG_SIG_ME_ADDITIONAL_DATA)
+                            pks_objects: List[G1Element] = [G1Element.from_bytes(pk) for pk in pairs_pks]
+                            if not AugSchemeMPL.aggregate_verify(
+                                pks_objects, pairs_msgs, block.transactions_info.aggregated_signature
+                            ):
+                                error_int = uint16(Err.BAD_AGGREGATE_SIGNATURE.value)
+                            else:
+                                successfully_validated_signatures = True
+
+                results.append(
+                    PreValidationResult(error_int, required_iters, npc_result, successfully_validated_signatures)
+                )
             except Exception:
                 error_stack = traceback.format_exc()
                 log.error(f"Exception: {error_stack}")
-                results.append(PreValidationResult(uint16(Err.UNKNOWN.value), None, None))
+                results.append(PreValidationResult(uint16(Err.UNKNOWN.value), None, None, False))
+    # In this case, we are validating header blocks
     elif header_blocks_pickled is not None:
         for i in range(len(header_blocks_pickled)):
             try:
                 header_block = HeaderBlock.from_bytes(header_blocks_pickled[i])
+                # TODO: address hint error and remove ignore
+                #       error: Argument 1 to "BlockCache" has incompatible type "Dict[bytes, BlockRecord]"; expected
+                #       "Dict[bytes32, BlockRecord]"  [arg-type]
                 required_iters, error = validate_finished_header_block(
                     constants,
-                    BlockCache(blocks),
+                    BlockCache(blocks),  # type: ignore[arg-type]
                     header_block,
                     check_filter,
                     expected_difficulty[i],
@@ -119,11 +157,11 @@ def batch_pre_validate_blocks(
                 error_int = None
                 if error is not None:
                     error_int = uint16(error.code.value)
-                results.append(PreValidationResult(error_int, required_iters, None))
+                results.append(PreValidationResult(error_int, required_iters, None, False))
             except Exception:
                 error_stack = traceback.format_exc()
                 log.error(f"Exception: {error_stack}")
-                results.append(PreValidationResult(uint16(Err.UNKNOWN.value), None, None))
+                results.append(PreValidationResult(uint16(Err.UNKNOWN.value), None, None, False))
     return [bytes(r) for r in results]
 
 
@@ -138,7 +176,9 @@ async def pre_validate_blocks_multiprocessing(
     get_block_generator: Optional[Callable],
     batch_size: int,
     wp_summaries: Optional[List[SubEpochSummary]] = None,
-) -> Optional[List[PreValidationResult]]:
+    *,
+    validate_signatures: bool = True,
+) -> List[PreValidationResult]:
     """
     This method must be called under the blockchain lock
     If all the full blocks pass pre-validation, (only validates header), returns the list of required iters.
@@ -162,7 +202,7 @@ async def pre_validate_blocks_multiprocessing(
     num_blocks_seen = 0
     if blocks[0].height > 0:
         if not block_records.contains_block(blocks[0].prev_header_hash):
-            return [PreValidationResult(uint16(Err.INVALID_PREV_BLOCK_HASH.value), None, None)]
+            return [PreValidationResult(uint16(Err.INVALID_PREV_BLOCK_HASH.value), None, None, False)]
         curr = block_records.block_record(blocks[0].prev_header_hash)
         num_sub_slots_to_look_for = 3 if curr.overflow else 2
         while (
@@ -210,7 +250,7 @@ async def pre_validate_blocks_multiprocessing(
             for i, block_i in enumerate(blocks):
                 if not block_record_was_present[i] and block_records.contains_block(block_i.header_hash):
                     block_records.remove_block_record(block_i.header_hash)
-            return None
+            return [PreValidationResult(uint16(Err.INVALID_POSPACE.value), None, None, False)]
 
         required_iters: uint64 = calculate_iterations_quality(
             constants.DIFFICULTY_CONSTANT_FACTOR,
@@ -220,20 +260,23 @@ async def pre_validate_blocks_multiprocessing(
             cc_sp_hash,
         )
 
-        block_rec = block_to_block_record(
-            constants,
-            block_records,
-            required_iters,
-            block,
-            None,
-        )
+        try:
+            block_rec = block_to_block_record(
+                constants,
+                block_records,
+                required_iters,
+                block,
+                None,
+            )
+        except ValueError:
+            return [PreValidationResult(uint16(Err.INVALID_SUB_EPOCH_SUMMARY.value), None, None, False)]
 
         if block_rec.sub_epoch_summary_included is not None and wp_summaries is not None:
             idx = int(block.height / constants.SUB_EPOCH_BLOCKS) - 1
             next_ses = wp_summaries[idx]
             if not block_rec.sub_epoch_summary_included.get_hash() == next_ses.get_hash():
                 log.error("sub_epoch_summary does not match wp sub_epoch_summary list")
-                return None
+                return [PreValidationResult(uint16(Err.INVALID_SUB_EPOCH_SUMMARY.value), None, None, False)]
         # Makes sure to not override the valid blocks already in block_records
         if not block_records.contains_block(block_rec.header_hash):
             block_records.add_block_record(block_rec)  # Temporarily add block to dict
@@ -286,7 +329,11 @@ async def pre_validate_blocks_multiprocessing(
                 try:
                     block_generator: Optional[BlockGenerator] = await get_block_generator(block, prev_blocks_dict)
                 except ValueError:
-                    return None
+                    return [
+                        PreValidationResult(
+                            uint16(Err.FAILED_GETTING_GENERATOR_MULTIPROCESSING.value), None, None, False
+                        )
+                    ]
                 if block_generator is not None:
                     previous_generators.append(bytes(block_generator))
                 else:
@@ -309,6 +356,7 @@ async def pre_validate_blocks_multiprocessing(
                 check_filter,
                 [diff_ssis[j][0] for j in range(i, end_i)],
                 [diff_ssis[j][1] for j in range(i, end_i)],
+                validate_signatures,
             )
         )
     # Collect all results into one flat list
@@ -323,7 +371,8 @@ def _run_generator(
     constants_dict: bytes,
     unfinished_block_bytes: bytes,
     block_generator_bytes: bytes,
-) -> Tuple[Optional[Err], Optional[bytes]]:
+    height: uint32,
+) -> Optional[bytes]:
     """
     Runs the CLVM generator from bytes inputs. This is meant to be called under a ProcessPoolExecutor, in order to
     validate the heavy parts of a block (clvm program) in a different process.
@@ -338,13 +387,11 @@ def _run_generator(
             block_generator,
             min(constants.MAX_BLOCK_COST_CLVM, unfinished_block.transactions_info.cost),
             cost_per_byte=constants.COST_PER_BYTE,
-            safe_mode=False,
+            mempool_mode=False,
+            height=height,
         )
-        if npc_result.error is not None:
-            return Err(npc_result.error), None
+        return bytes(npc_result)
     except ValidationError as e:
-        return e.code, None
+        return bytes(NPCResult(uint16(e.code.value), [], uint64(0)))
     except Exception:
-        return Err.UNKNOWN, None
-
-    return None, bytes(npc_result)
+        return bytes(NPCResult(uint16(Err.UNKNOWN.value), [], uint64(0)))
