@@ -19,10 +19,13 @@ class CoinRecord(Streamable):
     coin: Coin
     confirmed_block_index: uint32
     spent_block_index: uint32
-    spent: bool
     coinbase: bool
     timestamp: uint64  # Timestamp of the block at height confirmed_block_index
 
+    @property
+    def spent(self) -> bool:
+        return self.spent_block_index > 0
+
     @property
     def name(self) -> bytes32:
         return self.coin.name()
