@@ -1,15 +1,14 @@
 from typing import Dict, List, Optional, Tuple, Set
 
-from blspy import G1Element
+from clvm.casts import int_from_bytes
 
 from chia.types.announcement import Announcement
 from chia.types.name_puzzle_condition import NPC
 from chia.types.blockchain_format.coin import Coin
 from chia.types.blockchain_format.program import Program, SerializedProgram
-from chia.types.blockchain_format.sized_bytes import bytes32
+from chia.types.blockchain_format.sized_bytes import bytes32, bytes48
 from chia.types.condition_opcodes import ConditionOpcode
 from chia.types.condition_with_args import ConditionWithArgs
-from chia.util.clvm import int_from_bytes
 from chia.util.errors import ConsensusError, Err
 from chia.util.ints import uint64
 
@@ -66,8 +65,8 @@ def conditions_by_opcode(
     return d
 
 
-def pkm_pairs(npc_list: List[NPC], additional_data: bytes) -> Tuple[List[G1Element], List[bytes]]:
-    ret: Tuple[List[G1Element], List[bytes]] = ([], [])
+def pkm_pairs(npc_list: List[NPC], additional_data: bytes) -> Tuple[List[bytes48], List[bytes]]:
+    ret: Tuple[List[bytes48], List[bytes]] = ([], [])
 
     for npc in npc_list:
         for opcode, l in npc.conditions:
@@ -76,35 +75,35 @@ def pkm_pairs(npc_list: List[NPC], additional_data: bytes) -> Tuple[List[G1Eleme
                     assert len(cwa.vars) == 2
                     assert len(cwa.vars[0]) == 48 and len(cwa.vars[1]) <= 1024
                     assert cwa.vars[0] is not None and cwa.vars[1] is not None
-                    ret[0].append(G1Element.from_bytes(cwa.vars[0]))
+                    ret[0].append(bytes48(cwa.vars[0]))
                     ret[1].append(cwa.vars[1])
             elif opcode == ConditionOpcode.AGG_SIG_ME:
                 for cwa in l:
                     assert len(cwa.vars) == 2
                     assert len(cwa.vars[0]) == 48 and len(cwa.vars[1]) <= 1024
                     assert cwa.vars[0] is not None and cwa.vars[1] is not None
-                    ret[0].append(G1Element.from_bytes(cwa.vars[0]))
+                    ret[0].append(bytes48(cwa.vars[0]))
                     ret[1].append(cwa.vars[1] + npc.coin_name + additional_data)
     return ret
 
 
 def pkm_pairs_for_conditions_dict(
     conditions_dict: Dict[ConditionOpcode, List[ConditionWithArgs]], coin_name: bytes32, additional_data: bytes
-) -> List[Tuple[G1Element, bytes]]:
+) -> List[Tuple[bytes48, bytes]]:
     assert coin_name is not None
-    ret: List[Tuple[G1Element, bytes]] = []
+    ret: List[Tuple[bytes48, bytes]] = []
 
     for cwa in conditions_dict.get(ConditionOpcode.AGG_SIG_UNSAFE, []):
         assert len(cwa.vars) == 2
         assert len(cwa.vars[0]) == 48 and len(cwa.vars[1]) <= 1024
         assert cwa.vars[0] is not None and cwa.vars[1] is not None
-        ret.append((G1Element.from_bytes(cwa.vars[0]), cwa.vars[1]))
+        ret.append((bytes48(cwa.vars[0]), cwa.vars[1]))
 
     for cwa in conditions_dict.get(ConditionOpcode.AGG_SIG_ME, []):
         assert len(cwa.vars) == 2
         assert len(cwa.vars[0]) == 48 and len(cwa.vars[1]) <= 1024
         assert cwa.vars[0] is not None and cwa.vars[1] is not None
-        ret.append((G1Element.from_bytes(cwa.vars[0]), cwa.vars[1] + coin_name + additional_data))
+        ret.append((bytes48(cwa.vars[0]), cwa.vars[1] + coin_name + additional_data))
     return ret
 
 
@@ -116,7 +115,7 @@ def created_outputs_for_conditions_dict(
     for cvp in conditions_dict.get(ConditionOpcode.CREATE_COIN, []):
         puzzle_hash, amount_bin = cvp.vars[0], cvp.vars[1]
         amount = int_from_bytes(amount_bin)
-        coin = Coin(input_coin_name, puzzle_hash, uint64(amount))
+        coin = Coin(input_coin_name, bytes32(puzzle_hash), uint64(amount))
         output_coins.append(coin)
     return output_coins
 
