@@ -7,7 +7,7 @@ class Err(Enum):
     DOES_NOT_EXTEND = -1
     BAD_HEADER_SIGNATURE = -2
     MISSING_FROM_STORAGE = -3
-    INVALID_PROTOCOL_MESSAGE = -4
+    INVALID_PROTOCOL_MESSAGE = -4  # We WILL ban for a protocol violation.
     SELF_CONNECTION = -5
     INVALID_HANDSHAKE = -6
     INVALID_ACK = -7
@@ -129,7 +129,8 @@ class Err(Enum):
     INVALID_PREFARM = 104
     ASSERT_SECONDS_RELATIVE_FAILED = 105
     BAD_COINBASE_SIGNATURE = 106
-    INITIAL_TRANSACTION_FREEZE = 107
+
+    # INITIAL_TRANSACTION_FREEZE = 107      # removed
     NO_TRANSACTIONS_WHILE_SYNCING = 108
     ALREADY_INCLUDING_TRANSACTION = 109
     INCOMPATIBLE_NETWORK_ID = 110
@@ -150,6 +151,9 @@ class Err(Enum):
 
     INVALID_FEE_TOO_CLOSE_TO_ZERO = 123
     COIN_AMOUNT_NEGATIVE = 124
+    INTERNAL_PROTOCOL_ERROR = 125
+    INVALID_SPEND_BUNDLE = 126
+    FAILED_GETTING_GENERATOR_MULTIPROCESSING = 127
 
 
 class ValidationError(Exception):
