@@ -1,4 +1,5 @@
 from typing import Tuple
+from pathlib import Path
 
 import aiosqlite
 
@@ -16,5 +17,5 @@ async def create_ram_blockchain(consensus_constants: ConsensusConstants) -> Tupl
     block_store = await BlockStore.create(db_wrapper)
     coin_store = await CoinStore.create(db_wrapper)
     hint_store = await HintStore.create(db_wrapper)
-    blockchain = await Blockchain.create(coin_store, block_store, consensus_constants, hint_store)
+    blockchain = await Blockchain.create(coin_store, block_store, consensus_constants, hint_store, Path("."), 2)
     return connection, blockchain
