@@ -3,7 +3,7 @@ import logging
 from dataclasses import dataclass
 from pathlib import Path
 from shutil import rmtree
-from typing import Optional, List, Dict
+from typing import Any, Optional, List, Dict
 
 import pytest
 import pytest_asyncio
@@ -25,12 +25,12 @@ from chia.util.bech32m import encode_puzzle_hash
 from chia.util.byte_types import hexstr_to_bytes
 from chia.wallet.derive_keys import find_authentication_sk, find_owner_sk
 from chia.wallet.wallet_node import WalletNode
-from tests.block_tools import get_plot_dir
+from tests.block_tools import get_plot_dir, BlockTools
 from chia.util.config import load_config
 from chia.util.ints import uint16, uint32
 from chia.wallet.transaction_record import TransactionRecord
 from chia.wallet.util.wallet_types import WalletType
-from tests.setup_nodes import self_hostname, setup_simulators_and_wallets, bt
+from tests.setup_nodes import setup_simulators_and_wallets
 from tests.time_out_assert import time_out_assert
 from tests.util.socket import find_available_listen_port
 
@@ -43,23 +43,38 @@ def get_pool_plot_dir():
     return get_plot_dir() / Path("pool_tests")
 
 
+async def get_total_block_rewards(num_blocks):
+    funds = sum(
+        [calculate_pool_reward(uint32(i)) + calculate_base_farmer_reward(uint32(i)) for i in range(1, num_blocks)]
+    )
+    return funds
+
+
+async def farm_blocks(full_node_api, ph: bytes32, num_blocks: int):
+    for i in range(num_blocks):
+        await full_node_api.farm_new_transaction_block(FarmNewBlockProtocol(ph))
+    return num_blocks
+    # TODO also return calculated block rewards
+
+
 @dataclass
 class TemporaryPoolPlot:
+    bt: BlockTools
     p2_singleton_puzzle_hash: bytes32
     plot_id: Optional[bytes32] = None
 
     async def __aenter__(self):
-        plot_id: bytes32 = await bt.new_plot(self.p2_singleton_puzzle_hash, get_pool_plot_dir())
+        plot_id: bytes32 = await self.bt.new_plot(self.p2_singleton_puzzle_hash, get_pool_plot_dir())
         assert plot_id is not None
-        await bt.refresh_plots()
+        await self.bt.refresh_plots()
         self.plot_id = plot_id
         return self
 
     async def __aexit__(self, exc_type, exc_value, exc_traceback):
-        await bt.delete_plot(self.plot_id)
+        await self.bt.delete_plot(self.plot_id)
 
 
-async def create_pool_plot(p2_singleton_puzzle_hash: bytes32) -> Optional[bytes32]:
+async def create_pool_plot(bt: BlockTools, p2_singleton_puzzle_hash: bytes32) -> Optional[bytes32]:
     plot_id = await bt.new_plot(p2_singleton_puzzle_hash, get_pool_plot_dir())
     await bt.refresh_plots()
     return plot_id
@@ -73,66 +88,27 @@ async def wallet_is_synced(wallet_node: WalletNode, full_node_api):
     )
 
 
-@pytest.fixture(scope="session")
-def event_loop():
-    loop = asyncio.get_event_loop()
-    yield loop
-
-
 PREFARMED_BLOCKS = 4
 
 
-class TestPoolWalletRpc:
-    @pytest_asyncio.fixture(scope="function")
-    async def two_wallet_nodes(self):
-        async for _ in setup_simulators_and_wallets(1, 2, {}):
-            yield _
+@pytest_asyncio.fixture(scope="function")
+async def two_wallet_nodes():
+    async for _ in setup_simulators_and_wallets(1, 2, {}):
+        yield _
 
-    @pytest_asyncio.fixture(scope="function")
-    async def one_wallet_node_and_rpc(self):
-        rmtree(get_pool_plot_dir(), ignore_errors=True)
-        async for nodes in setup_simulators_and_wallets(1, 1, {}):
-            full_nodes, wallets = nodes
-            full_node_api = full_nodes[0]
-            wallet_node_0, wallet_server_0 = wallets[0]
 
-            wallet_0 = wallet_node_0.wallet_state_manager.main_wallet
-            our_ph = await wallet_0.get_new_puzzlehash()
-            await self.farm_blocks(full_node_api, our_ph, PREFARMED_BLOCKS)
-
-            api_user = WalletRpcApi(wallet_node_0)
-            config = bt.config
-            daemon_port = config["daemon_port"]
-            test_rpc_port = find_available_listen_port("rpc_port")
-
-            rpc_cleanup = await start_rpc_server(
-                api_user,
-                self_hostname,
-                daemon_port,
-                test_rpc_port,
-                lambda x: None,
-                bt.root_path,
-                config,
-                connect_to_daemon=False,
-            )
-            client = await WalletRpcClient.create(self_hostname, test_rpc_port, bt.root_path, config)
-
-            yield client, wallet_node_0, full_node_api
-
-            client.close()
-            await client.await_closed()
-            await rpc_cleanup()
-
-    @pytest_asyncio.fixture(scope="function")
-    async def setup(self, two_wallet_nodes):
-        rmtree(get_pool_plot_dir(), ignore_errors=True)
-        full_nodes, wallets = two_wallet_nodes
+@pytest_asyncio.fixture(scope="function")
+async def one_wallet_node_and_rpc(bt, self_hostname):
+    rmtree(get_pool_plot_dir(), ignore_errors=True)
+    async for nodes in setup_simulators_and_wallets(1, 1, {}):
+        full_nodes, wallets = nodes
+        full_node_api = full_nodes[0]
         wallet_node_0, wallet_server_0 = wallets[0]
-        wallet_node_1, wallet_server_1 = wallets[1]
-        our_ph_record = await wallet_node_0.wallet_state_manager.get_unused_derivation_record(1, False, True)
-        pool_ph_record = await wallet_node_1.wallet_state_manager.get_unused_derivation_record(1, False, True)
-        our_ph = our_ph_record.puzzle_hash
-        pool_ph = pool_ph_record.puzzle_hash
+
+        wallet_0 = wallet_node_0.wallet_state_manager.main_wallet
+        our_ph = await wallet_0.get_new_puzzlehash()
+        await farm_blocks(full_node_api, our_ph, PREFARMED_BLOCKS)
+
         api_user = WalletRpcApi(wallet_node_0)
         config = bt.config
         daemon_port = config["daemon_port"]
@@ -150,30 +126,54 @@ class TestPoolWalletRpc:
         )
         client = await WalletRpcClient.create(self_hostname, test_rpc_port, bt.root_path, config)
 
-        return (
-            full_nodes,
-            [wallet_node_0, wallet_node_1],
-            [our_ph, pool_ph],
-            client,  # wallet rpc client
-            rpc_cleanup,
-        )
+        yield client, wallet_node_0, full_node_api
 
-    async def get_total_block_rewards(self, num_blocks):
-        funds = sum(
-            [calculate_pool_reward(uint32(i)) + calculate_base_farmer_reward(uint32(i)) for i in range(1, num_blocks)]
-        )
-        return funds
+        client.close()
+        await client.await_closed()
+        await rpc_cleanup()
 
-    async def farm_blocks(self, full_node_api, ph: bytes32, num_blocks: int):
-        for i in range(num_blocks):
-            await full_node_api.farm_new_transaction_block(FarmNewBlockProtocol(ph))
-        return num_blocks
-        # TODO also return calculated block rewards
 
+@pytest_asyncio.fixture(scope="function")
+async def setup(two_wallet_nodes, bt, self_hostname):
+    rmtree(get_pool_plot_dir(), ignore_errors=True)
+    full_nodes, wallets = two_wallet_nodes
+    wallet_node_0, wallet_server_0 = wallets[0]
+    wallet_node_1, wallet_server_1 = wallets[1]
+    our_ph_record = await wallet_node_0.wallet_state_manager.get_unused_derivation_record(1, False, True)
+    pool_ph_record = await wallet_node_1.wallet_state_manager.get_unused_derivation_record(1, False, True)
+    our_ph = our_ph_record.puzzle_hash
+    pool_ph = pool_ph_record.puzzle_hash
+    api_user = WalletRpcApi(wallet_node_0)
+    config = bt.config
+    daemon_port = config["daemon_port"]
+    test_rpc_port = find_available_listen_port("rpc_port")
+
+    rpc_cleanup = await start_rpc_server(
+        api_user,
+        self_hostname,
+        daemon_port,
+        test_rpc_port,
+        lambda x: None,
+        bt.root_path,
+        config,
+        connect_to_daemon=False,
+    )
+    client = await WalletRpcClient.create(self_hostname, test_rpc_port, bt.root_path, config)
+
+    return (
+        full_nodes,
+        [wallet_node_0, wallet_node_1],
+        [our_ph, pool_ph],
+        client,  # wallet rpc client
+        rpc_cleanup,
+    )
+
+
+class TestPoolWalletRpc:
     @pytest.mark.asyncio
     @pytest.mark.parametrize("trusted", [True, False])
     @pytest.mark.parametrize("fee", [0, FEE_AMOUNT])
-    async def test_create_new_pool_wallet_self_farm(self, one_wallet_node_and_rpc, fee, trusted):
+    async def test_create_new_pool_wallet_self_farm(self, one_wallet_node_and_rpc, fee, trusted, self_hostname):
         client, wallet_node_0, full_node_api = one_wallet_node_and_rpc
         wallet_0 = wallet_node_0.wallet_state_manager.main_wallet
         if trusted:
@@ -186,7 +186,7 @@ class TestPoolWalletRpc:
         await wallet_node_0.server.start_client(
             PeerInfo(self_hostname, uint16(full_node_api.full_node.server._port)), None
         )
-        total_block_rewards = await self.get_total_block_rewards(PREFARMED_BLOCKS)
+        total_block_rewards = await get_total_block_rewards(PREFARMED_BLOCKS)
         await time_out_assert(10, wallet_0.get_confirmed_balance, total_block_rewards)
         await time_out_assert(10, wallet_node_0.wallet_state_manager.blockchain.get_peak_height, PREFARMED_BLOCKS)
 
@@ -206,7 +206,7 @@ class TestPoolWalletRpc:
             creation_tx.name,
         )
 
-        await self.farm_blocks(full_node_api, our_ph, 6)
+        await farm_blocks(full_node_api, our_ph, 6)
         assert full_node_api.full_node.mempool_manager.get_spendbundle(creation_tx.name) is None
 
         await time_out_assert(10, wallet_is_synced, True, wallet_node_0, full_node_api)
@@ -249,7 +249,7 @@ class TestPoolWalletRpc:
     @pytest.mark.asyncio
     @pytest.mark.parametrize("trusted", [True, False])
     @pytest.mark.parametrize("fee", [0, FEE_AMOUNT])
-    async def test_create_new_pool_wallet_farm_to_pool(self, one_wallet_node_and_rpc, fee, trusted):
+    async def test_create_new_pool_wallet_farm_to_pool(self, one_wallet_node_and_rpc, fee, trusted, self_hostname):
         client, wallet_node_0, full_node_api = one_wallet_node_and_rpc
         wallet_0 = wallet_node_0.wallet_state_manager.main_wallet
         if trusted:
@@ -262,7 +262,7 @@ class TestPoolWalletRpc:
         await wallet_node_0.server.start_client(
             PeerInfo(self_hostname, uint16(full_node_api.full_node.server._port)), None
         )
-        total_block_rewards = await self.get_total_block_rewards(PREFARMED_BLOCKS)
+        total_block_rewards = await get_total_block_rewards(PREFARMED_BLOCKS)
         await time_out_assert(10, wallet_node_0.wallet_state_manager.blockchain.get_peak_height, PREFARMED_BLOCKS)
 
         await time_out_assert(10, wallet_0.get_confirmed_balance, total_block_rewards)
@@ -285,7 +285,7 @@ class TestPoolWalletRpc:
             creation_tx.name,
         )
 
-        await self.farm_blocks(full_node_api, our_ph, 6)
+        await farm_blocks(full_node_api, our_ph, 6)
         assert full_node_api.full_node.mempool_manager.get_spendbundle(creation_tx.name) is None
 
         await time_out_assert(5, wallet_is_synced, True, wallet_node_0, full_node_api)
@@ -328,7 +328,7 @@ class TestPoolWalletRpc:
     @pytest.mark.asyncio
     @pytest.mark.parametrize("trusted", [True, False])
     @pytest.mark.parametrize("fee", [0, FEE_AMOUNT])
-    async def test_create_multiple_pool_wallets(self, one_wallet_node_and_rpc, fee, trusted):
+    async def test_create_multiple_pool_wallets(self, one_wallet_node_and_rpc, fee, trusted, self_hostname):
         client, wallet_node_0, full_node_api = one_wallet_node_and_rpc
         if trusted:
             wallet_node_0.config["trusted_peers"] = {
@@ -340,7 +340,7 @@ class TestPoolWalletRpc:
         await wallet_node_0.server.start_client(
             PeerInfo(self_hostname, uint16(full_node_api.full_node.server._port)), None
         )
-        total_block_rewards = await self.get_total_block_rewards(PREFARMED_BLOCKS)
+        total_block_rewards = await get_total_block_rewards(PREFARMED_BLOCKS)
         wallet_0 = wallet_node_0.wallet_state_manager.main_wallet
         await time_out_assert(10, wallet_0.get_confirmed_balance, total_block_rewards)
         await time_out_assert(10, wallet_node_0.wallet_state_manager.blockchain.get_peak_height, PREFARMED_BLOCKS)
@@ -373,7 +373,7 @@ class TestPoolWalletRpc:
             creation_tx_2.name,
         )
 
-        await self.farm_blocks(full_node_api, our_ph_2, 6)
+        await farm_blocks(full_node_api, our_ph_2, 6)
         assert full_node_api.full_node.mempool_manager.get_spendbundle(creation_tx.name) is None
         assert full_node_api.full_node.mempool_manager.get_spendbundle(creation_tx_2.name) is None
 
@@ -414,7 +414,7 @@ class TestPoolWalletRpc:
             cat_0_id = res["wallet_id"]
             asset_id = bytes.fromhex(res["asset_id"])
             assert len(asset_id) > 0
-            await self.farm_blocks(full_node_api, our_ph_2, 6)
+            await farm_blocks(full_node_api, our_ph_2, 6)
             await time_out_assert(20, wallet_is_synced, True, wallet_node_0, full_node_api)
             bal_0 = await client.get_wallet_balance(cat_0_id)
             assert bal_0["confirmed_wallet_balance"] == 20
@@ -433,7 +433,7 @@ class TestPoolWalletRpc:
                     creation_tx_3.spend_bundle,
                     creation_tx_3.name,
                 )
-                await self.farm_blocks(full_node_api, our_ph_2, 2)
+                await farm_blocks(full_node_api, our_ph_2, 2)
                 await time_out_assert(20, wallet_is_synced, True, wallet_node_0, full_node_api)
 
                 full_config: Dict = load_config(wallet_0.wallet_state_manager.root_path, "config.yaml")
@@ -458,7 +458,7 @@ class TestPoolWalletRpc:
     @pytest.mark.asyncio
     @pytest.mark.parametrize("trusted", [True, False])
     @pytest.mark.parametrize("fee", [0, FEE_AMOUNT])
-    async def test_absorb_self(self, one_wallet_node_and_rpc, fee, trusted):
+    async def test_absorb_self(self, one_wallet_node_and_rpc, fee, trusted, bt, self_hostname):
         client, wallet_node_0, full_node_api = one_wallet_node_and_rpc
         if trusted:
             wallet_node_0.config["trusted_peers"] = {
@@ -471,7 +471,7 @@ class TestPoolWalletRpc:
             PeerInfo(self_hostname, uint16(full_node_api.full_node.server._port)), None
         )
         wallet_0 = wallet_node_0.wallet_state_manager.main_wallet
-        total_block_rewards = await self.get_total_block_rewards(PREFARMED_BLOCKS)
+        total_block_rewards = await get_total_block_rewards(PREFARMED_BLOCKS)
         await time_out_assert(10, wallet_0.get_confirmed_balance, total_block_rewards)
         await time_out_assert(10, wallet_node_0.wallet_state_manager.blockchain.get_peak_height, PREFARMED_BLOCKS)
 
@@ -492,12 +492,12 @@ class TestPoolWalletRpc:
             creation_tx.spend_bundle,
             creation_tx.name,
         )
-        await self.farm_blocks(full_node_api, our_ph, 1)
+        await farm_blocks(full_node_api, our_ph, 1)
         await asyncio.sleep(2)
         status: PoolWalletInfo = (await client.pw_status(2))[0]
 
         assert status.current.state == PoolSingletonState.SELF_POOLING.value
-        async with TemporaryPoolPlot(status.p2_singleton_puzzle_hash) as pool_plot:
+        async with TemporaryPoolPlot(bt, status.p2_singleton_puzzle_hash) as pool_plot:
             all_blocks = await full_node_api.get_all_full_blocks()
             blocks = bt.get_consecutive_blocks(
                 3,
@@ -523,7 +523,7 @@ class TestPoolWalletRpc:
                 absorb_tx.spend_bundle,
                 absorb_tx.name,
             )
-            await self.farm_blocks(full_node_api, our_ph, 2)
+            await farm_blocks(full_node_api, our_ph, 2)
             await asyncio.sleep(2)
             new_status: PoolWalletInfo = (await client.pw_status(2))[0]
             assert status.current == new_status.current
@@ -542,7 +542,7 @@ class TestPoolWalletRpc:
                 absorb_tx1.name,
             )
 
-            await self.farm_blocks(full_node_api, our_ph, 2)
+            await farm_blocks(full_node_api, our_ph, 2)
             await asyncio.sleep(2)
             bal = await client.get_wallet_balance(2)
             assert bal["confirmed_wallet_balance"] == 0
@@ -559,7 +559,7 @@ class TestPoolWalletRpc:
                 tr.spend_bundle,
                 tr.name,
             )
-            await self.farm_blocks(full_node_api, our_ph, 2)
+            await farm_blocks(full_node_api, our_ph, 2)
             # Balance ignores non coinbase TX
             bal = await client.get_wallet_balance(2)
             assert bal["confirmed_wallet_balance"] == 0
@@ -574,7 +574,7 @@ class TestPoolWalletRpc:
     @pytest.mark.asyncio
     @pytest.mark.parametrize("trusted", [True, False])
     @pytest.mark.parametrize("fee", [0, FEE_AMOUNT])
-    async def test_absorb_pooling(self, one_wallet_node_and_rpc, fee, trusted):
+    async def test_absorb_pooling(self, one_wallet_node_and_rpc, fee, trusted, bt, self_hostname):
         client, wallet_node_0, full_node_api = one_wallet_node_and_rpc
         if trusted:
             wallet_node_0.config["trusted_peers"] = {
@@ -587,7 +587,7 @@ class TestPoolWalletRpc:
             PeerInfo(self_hostname, uint16(full_node_api.full_node.server._port)), None
         )
         wallet_0 = wallet_node_0.wallet_state_manager.main_wallet
-        total_block_rewards = await self.get_total_block_rewards(PREFARMED_BLOCKS)
+        total_block_rewards = await get_total_block_rewards(PREFARMED_BLOCKS)
         await time_out_assert(10, wallet_0.get_confirmed_balance, total_block_rewards)
         await time_out_assert(10, wallet_node_0.wallet_state_manager.blockchain.get_peak_height, PREFARMED_BLOCKS)
 
@@ -609,12 +609,12 @@ class TestPoolWalletRpc:
             creation_tx.spend_bundle,
             creation_tx.name,
         )
-        await self.farm_blocks(full_node_api, our_ph, 1)
+        await farm_blocks(full_node_api, our_ph, 1)
         await asyncio.sleep(2)
         status: PoolWalletInfo = (await client.pw_status(2))[0]
 
         assert status.current.state == PoolSingletonState.FARMING_TO_POOL.value
-        async with TemporaryPoolPlot(status.p2_singleton_puzzle_hash) as pool_plot:
+        async with TemporaryPoolPlot(bt, status.p2_singleton_puzzle_hash) as pool_plot:
             all_blocks = await full_node_api.get_all_full_blocks()
             blocks = bt.get_consecutive_blocks(
                 3,
@@ -640,7 +640,7 @@ class TestPoolWalletRpc:
                 absorb_tx.spend_bundle,
                 absorb_tx.name,
             )
-            await self.farm_blocks(full_node_api, our_ph, 2)
+            await farm_blocks(full_node_api, our_ph, 2)
             await asyncio.sleep(5)
             new_status: PoolWalletInfo = (await client.pw_status(2))[0]
             assert status.current == new_status.current
@@ -665,7 +665,7 @@ class TestPoolWalletRpc:
                 assert ret["fee_transaction"].fee_amount == fee
             assert absorb_tx.fee_amount == fee
 
-            await self.farm_blocks(full_node_api, our_ph, 2)
+            await farm_blocks(full_node_api, our_ph, 2)
             await asyncio.sleep(5)
             bal = await client.get_wallet_balance(2)
             assert bal["confirmed_wallet_balance"] == 0
@@ -704,7 +704,7 @@ class TestPoolWalletRpc:
                         absorb_tx.name,
                     )
 
-                    await self.farm_blocks(full_node_api, our_ph, 2)
+                    await farm_blocks(full_node_api, our_ph, 2)
                     await asyncio.sleep(2)
                     new_status: PoolWalletInfo = (await client.pw_status(2))[0]
                     assert status.current == new_status.current
@@ -722,7 +722,7 @@ class TestPoolWalletRpc:
     @pytest.mark.asyncio
     @pytest.mark.parametrize("trusted", [True])
     @pytest.mark.parametrize("fee", [0])
-    async def test_self_pooling_to_pooling(self, setup, fee, trusted):
+    async def test_self_pooling_to_pooling(self, setup, fee, trusted, self_hostname):
         """This tests self-pooling -> pooling"""
         num_blocks = 4  # Num blocks to farm at a time
         total_blocks = 0  # Total blocks farmed so far
@@ -744,8 +744,8 @@ class TestPoolWalletRpc:
         )
 
         try:
-            total_blocks += await self.farm_blocks(full_node_api, our_ph, num_blocks)
-            total_block_rewards = await self.get_total_block_rewards(total_blocks)
+            total_blocks += await farm_blocks(full_node_api, our_ph, num_blocks)
+            total_block_rewards = await get_total_block_rewards(total_blocks)
 
             await time_out_assert(10, wallets[0].get_unconfirmed_balance, total_block_rewards)
             await time_out_assert(10, wallets[0].get_confirmed_balance, total_block_rewards)
@@ -778,7 +778,7 @@ class TestPoolWalletRpc:
                 creation_tx_2.name,
             )
 
-            await self.farm_blocks(full_node_api, our_ph, 6)
+            await farm_blocks(full_node_api, our_ph, 6)
             assert full_node_api.full_node.mempool_manager.get_spendbundle(creation_tx.name) is None
             await time_out_assert(10, wallet_is_synced, True, wallet_node_0, full_node_api)
 
@@ -802,20 +802,24 @@ class TestPoolWalletRpc:
             assert status.target is None
             assert status_2.target is None
 
-            join_pool_tx: TransactionRecord = await client.pw_join_pool(
-                wallet_id,
-                pool_ph,
-                "https://pool.example.com",
-                10,
-                fee,
-            )
-            join_pool_tx_2: TransactionRecord = await client.pw_join_pool(
-                wallet_id_2,
-                pool_ph,
-                "https://pool.example.com",
-                10,
-                fee,
-            )
+            join_pool_tx: TransactionRecord = (
+                await client.pw_join_pool(
+                    wallet_id,
+                    pool_ph,
+                    "https://pool.example.com",
+                    10,
+                    fee,
+                )
+            )["transaction"]
+            join_pool_tx_2: TransactionRecord = (
+                await client.pw_join_pool(
+                    wallet_id_2,
+                    pool_ph,
+                    "https://pool.example.com",
+                    10,
+                    fee,
+                )
+            )["transaction"]
             assert join_pool_tx is not None
             assert join_pool_tx_2 is not None
 
@@ -836,9 +840,9 @@ class TestPoolWalletRpc:
             assert status_2.target is not None
             assert status_2.target.state == PoolSingletonState.FARMING_TO_POOL.value
 
-            await self.farm_blocks(full_node_api, our_ph, 6)
+            await farm_blocks(full_node_api, our_ph, 6)
 
-            total_blocks += await self.farm_blocks(full_node_api, our_ph, num_blocks)
+            total_blocks += await farm_blocks(full_node_api, our_ph, num_blocks)
 
             async def status_is_farming_to_pool(w_id: int):
                 pw_status: PoolWalletInfo = (await client.pw_status(w_id))[0]
@@ -859,7 +863,7 @@ class TestPoolWalletRpc:
         "fee",
         [0, FEE_AMOUNT],
     )
-    async def test_leave_pool(self, setup, fee, trusted):
+    async def test_leave_pool(self, setup, fee, trusted, self_hostname):
         """This tests self-pooling -> pooling -> escaping -> self pooling"""
         full_nodes, wallet_nodes, receive_address, client, rpc_cleanup = setup
         our_ph = receive_address[0]
@@ -886,7 +890,7 @@ class TestPoolWalletRpc:
                     assert False
 
             async def have_chia():
-                await self.farm_blocks(full_node_api, our_ph, 1)
+                await farm_blocks(full_node_api, our_ph, 1)
                 return (await wallets[0].get_confirmed_balance()) > 0
 
             await time_out_assert(timeout=WAIT_SECS, function=have_chia)
@@ -903,7 +907,7 @@ class TestPoolWalletRpc:
                 creation_tx.name,
             )
 
-            await self.farm_blocks(full_node_api, our_ph, 6)
+            await farm_blocks(full_node_api, our_ph, 6)
             assert full_node_api.full_node.mempool_manager.get_spendbundle(creation_tx.name) is None
 
             await time_out_assert(10, wallet_is_synced, True, wallet_nodes[0], full_node_api)
@@ -919,13 +923,15 @@ class TestPoolWalletRpc:
             assert status.current.state == PoolSingletonState.SELF_POOLING.value
             assert status.target is None
 
-            join_pool_tx: TransactionRecord = await client.pw_join_pool(
-                wallet_id,
-                pool_ph,
-                "https://pool.example.com",
-                5,
-                fee,
-            )
+            join_pool_tx: TransactionRecord = (
+                await client.pw_join_pool(
+                    wallet_id,
+                    pool_ph,
+                    "https://pool.example.com",
+                    5,
+                    fee,
+                )
+            )["transaction"]
             assert join_pool_tx is not None
 
             status: PoolWalletInfo = (await client.pw_status(wallet_id))[0]
@@ -943,7 +949,7 @@ class TestPoolWalletRpc:
             assert status.target.version == 1
 
             async def status_is_farming_to_pool():
-                await self.farm_blocks(full_node_api, our_ph, 1)
+                await farm_blocks(full_node_api, our_ph, 1)
                 pw_status: PoolWalletInfo = (await client.pw_status(wallet_id))[0]
                 return pw_status.current.state == PoolSingletonState.FARMING_TO_POOL.value
 
@@ -953,12 +959,12 @@ class TestPoolWalletRpc:
 
             status: PoolWalletInfo = (await client.pw_status(wallet_id))[0]
 
-            leave_pool_tx: TransactionRecord = await client.pw_self_pool(wallet_id, fee)
-            assert leave_pool_tx.wallet_id == wallet_id
-            assert leave_pool_tx.amount == 1
+            leave_pool_tx: Dict[str, Any] = await client.pw_self_pool(wallet_id, fee)
+            assert leave_pool_tx["transaction"].wallet_id == wallet_id
+            assert leave_pool_tx["transaction"].amount == 1
 
             async def status_is_leaving():
-                await self.farm_blocks(full_node_api, our_ph, 1)
+                await farm_blocks(full_node_api, our_ph, 1)
                 pw_status: PoolWalletInfo = (await client.pw_status(wallet_id))[0]
                 return pw_status.current.state == PoolSingletonState.LEAVING_POOL.value
 
@@ -966,7 +972,7 @@ class TestPoolWalletRpc:
 
             async def status_is_self_pooling():
                 # Farm enough blocks to wait for relative_lock_height
-                await self.farm_blocks(full_node_api, our_ph, 1)
+                await farm_blocks(full_node_api, our_ph, 1)
                 pw_status: PoolWalletInfo = (await client.pw_status(wallet_id))[0]
                 return pw_status.current.state == PoolSingletonState.SELF_POOLING.value
 
@@ -981,7 +987,7 @@ class TestPoolWalletRpc:
     @pytest.mark.asyncio
     @pytest.mark.parametrize("trusted", [True, False])
     @pytest.mark.parametrize("fee", [0, FEE_AMOUNT])
-    async def test_change_pools(self, setup, fee, trusted):
+    async def test_change_pools(self, setup, fee, trusted, self_hostname):
         """This tests Pool A -> escaping -> Pool B"""
         full_nodes, wallet_nodes, receive_address, client, rpc_cleanup = setup
         our_ph = receive_address[0]
@@ -1009,7 +1015,7 @@ class TestPoolWalletRpc:
                     assert False
 
             async def have_chia():
-                await self.farm_blocks(full_node_api, our_ph, 1)
+                await farm_blocks(full_node_api, our_ph, 1)
                 return (await wallets[0].get_confirmed_balance()) > 0
 
             await time_out_assert(timeout=WAIT_SECS, function=have_chia)
@@ -1026,7 +1032,7 @@ class TestPoolWalletRpc:
                 creation_tx.name,
             )
 
-            await self.farm_blocks(full_node_api, our_ph, 6)
+            await farm_blocks(full_node_api, our_ph, 6)
             assert full_node_api.full_node.mempool_manager.get_spendbundle(creation_tx.name) is None
 
             await time_out_assert(10, wallet_is_synced, True, wallet_nodes[0], full_node_api)
@@ -1043,7 +1049,7 @@ class TestPoolWalletRpc:
             assert status.target is None
 
             async def status_is_farming_to_pool():
-                await self.farm_blocks(full_node_api, our_ph, 1)
+                await farm_blocks(full_node_api, our_ph, 1)
                 pw_status: PoolWalletInfo = (await client.pw_status(wallet_id))[0]
                 return pw_status.current.state == PoolSingletonState.FARMING_TO_POOL.value
 
@@ -1054,17 +1060,19 @@ class TestPoolWalletRpc:
             assert pw_info.current.relative_lock_height == 5
             status: PoolWalletInfo = (await client.pw_status(wallet_id))[0]
 
-            join_pool_tx: TransactionRecord = await client.pw_join_pool(
-                wallet_id,
-                pool_b_ph,
-                "https://pool-b.org",
-                10,
-                fee,
-            )
+            join_pool_tx: TransactionRecord = (
+                await client.pw_join_pool(
+                    wallet_id,
+                    pool_b_ph,
+                    "https://pool-b.org",
+                    10,
+                    fee,
+                )
+            )["transaction"]
             assert join_pool_tx is not None
 
             async def status_is_leaving():
-                await self.farm_blocks(full_node_api, our_ph, 1)
+                await farm_blocks(full_node_api, our_ph, 1)
                 pw_status: PoolWalletInfo = (await client.pw_status(wallet_id))[0]
                 return pw_status.current.state == PoolSingletonState.LEAVING_POOL.value
 
@@ -1085,7 +1093,7 @@ class TestPoolWalletRpc:
     @pytest.mark.asyncio
     @pytest.mark.parametrize("trusted", [True, False])
     @pytest.mark.parametrize("fee", [0, FEE_AMOUNT])
-    async def test_change_pools_reorg(self, setup, fee, trusted):
+    async def test_change_pools_reorg(self, setup, fee, trusted, bt, self_hostname):
         """This tests Pool A -> escaping -> reorg -> escaping -> Pool B"""
         full_nodes, wallet_nodes, receive_address, client, rpc_cleanup = setup
         our_ph = receive_address[0]
@@ -1112,7 +1120,7 @@ class TestPoolWalletRpc:
                     assert False
 
             async def have_chia():
-                await self.farm_blocks(full_node_api, our_ph, 1)
+                await farm_blocks(full_node_api, our_ph, 1)
                 return (await wallets[0].get_confirmed_balance()) > 0
 
             await time_out_assert(timeout=WAIT_SECS, function=have_chia)
@@ -1129,7 +1137,7 @@ class TestPoolWalletRpc:
                 creation_tx.name,
             )
 
-            await self.farm_blocks(full_node_api, our_ph, 6)
+            await farm_blocks(full_node_api, our_ph, 6)
             assert full_node_api.full_node.mempool_manager.get_spendbundle(creation_tx.name) is None
 
             await time_out_assert(5, wallet_is_synced, True, wallet_nodes[0], full_node_api)
@@ -1146,7 +1154,7 @@ class TestPoolWalletRpc:
             assert status.target is None
 
             async def status_is_farming_to_pool():
-                await self.farm_blocks(full_node_api, our_ph, 1)
+                await farm_blocks(full_node_api, our_ph, 1)
                 pw_status: PoolWalletInfo = (await client.pw_status(wallet_id))[0]
                 return pw_status.current.state == PoolSingletonState.FARMING_TO_POOL.value
 
@@ -1156,13 +1164,15 @@ class TestPoolWalletRpc:
             assert pw_info.current.pool_url == "https://pool-a.org"
             assert pw_info.current.relative_lock_height == 5
 
-            join_pool_tx: TransactionRecord = await client.pw_join_pool(
-                wallet_id,
-                pool_b_ph,
-                "https://pool-b.org",
-                10,
-                fee,
-            )
+            join_pool_tx: TransactionRecord = (
+                await client.pw_join_pool(
+                    wallet_id,
+                    pool_b_ph,
+                    "https://pool-b.org",
+                    10,
+                    fee,
+                )
+            )["transaction"]
             assert join_pool_tx is not None
             await time_out_assert(
                 10,
@@ -1170,7 +1180,7 @@ class TestPoolWalletRpc:
                 join_pool_tx.spend_bundle,
                 join_pool_tx.name,
             )
-            await self.farm_blocks(full_node_api, our_ph, 1)
+            await farm_blocks(full_node_api, our_ph, 1)
 
             async def status_is_leaving_no_blocks():
                 pw_status: PoolWalletInfo = (await client.pw_status(wallet_id))[0]
