@@ -6,10 +6,11 @@ from chia.types.blockchain_format.sized_bytes import bytes32
 from chia.types.full_block import FullBlock
 from chia.types.generator_types import BlockGenerator
 from chia.util.generator_tools import additions_for_npc
+from chia.util.ints import uint32
 
 
 def run_and_get_removals_and_additions(
-    block: FullBlock, max_cost: int, cost_per_byte: int, safe_mode=False
+    block: FullBlock, max_cost: int, *, cost_per_byte: int, height: uint32, mempool_mode=False
 ) -> Tuple[List[bytes32], List[Coin]]:
     removals: List[bytes32] = []
     additions: List[Coin] = []
@@ -20,7 +21,11 @@ def run_and_get_removals_and_additions(
 
     if block.transactions_generator is not None:
         npc_result = get_name_puzzle_conditions(
-            BlockGenerator(block.transactions_generator, []), max_cost, cost_per_byte=cost_per_byte, safe_mode=safe_mode
+            BlockGenerator(block.transactions_generator, [], []),
+            max_cost,
+            cost_per_byte=cost_per_byte,
+            mempool_mode=mempool_mode,
+            height=height,
         )
         # build removals list
         for npc in npc_result.npc_list:
