@@ -1,5 +1,3 @@
-import asyncio
-
 import pytest
 import pytest_asyncio
 
@@ -7,25 +5,20 @@ from chia.simulator.simulator_protocol import FarmNewBlockProtocol
 from chia.types.peer_info import PeerInfo
 from chia.util.ints import uint16, uint64
 from chia.wallet.rl_wallet.rl_wallet import RLWallet
-from tests.setup_nodes import self_hostname, setup_simulators_and_wallets
+from tests.setup_nodes import setup_simulators_and_wallets
 from tests.time_out_assert import time_out_assert
 
 
-@pytest.fixture(scope="module")
-def event_loop():
-    loop = asyncio.get_event_loop()
-    yield loop
+@pytest_asyncio.fixture(scope="function")
+async def two_wallet_nodes():
+    async for _ in setup_simulators_and_wallets(1, 2, {}):
+        yield _
 
 
 class TestCATWallet:
-    @pytest_asyncio.fixture(scope="function")
-    async def two_wallet_nodes(self):
-        async for _ in setup_simulators_and_wallets(1, 2, {}):
-            yield _
-
     @pytest.mark.asyncio
     @pytest.mark.skip
-    async def test_create_rl_coin(self, two_wallet_nodes):
+    async def test_create_rl_coin(self, two_wallet_nodes, self_hostname):
         num_blocks = 4
         full_nodes, wallets = two_wallet_nodes
         full_node_api = full_nodes[0]
