@@ -1,4 +1,3 @@
-import asyncio
 from pathlib import Path
 from secrets import token_bytes
 
@@ -13,12 +12,6 @@ from chia.wallet.util.wallet_types import WalletType
 from chia.wallet.wallet_puzzle_store import WalletPuzzleStore
 
 
-@pytest.fixture(scope="module")
-def event_loop():
-    loop = asyncio.get_event_loop()
-    yield loop
-
-
 class TestPuzzleStore:
     @pytest.mark.asyncio
     async def test_puzzle_store(self):
